@@ -44,9 +44,11 @@ from ._gi import _gobject
 from ._gi import _API
 from ._gi import Repository
 from ._gi import PyGIDeprecationWarning
+from ._gi import PyGIWarning
 
 _API = _API  # pyflakes
 PyGIDeprecationWarning = PyGIDeprecationWarning
+PyGIWarning = PyGIWarning
 
 _versions = {}
 _overridesdir = os.path.join(os.path.dirname(__file__), 'overrides')
