@@ -23,7 +23,6 @@
 from __future__ import absolute_import
 
 import sys
-import types
 import importlib
 
 _have_py3 = (sys.version_info[0] >= 3)
@@ -35,7 +34,6 @@ except AttributeError:
     from string import maketrans
 
 import gi
-from .overrides import registry
 
 from ._gi import \
     Repository, \
@@ -54,15 +52,15 @@ from ._gi import \
     enum_add, \
     enum_register_new_gtype_and_add, \
     flags_add, \
-    flags_register_new_gtype_and_add
+    flags_register_new_gtype_and_add, \
+    _gobject
 from .types import \
     GObjectMeta, \
     StructMeta
 
-from ._gobject._gobject import \
-    GInterface
+GInterface = _gobject.GInterface
 
-from ._gobject.constants import \
+from ._constants import \
     TYPE_NONE, \
     TYPE_BOXED, \
     TYPE_POINTER, \
@@ -273,69 +271,3 @@ def get_introspection_module(namespace):
     module = IntrospectionModule(namespace, version)
     _introspection_modules[namespace] = module
     return module
-
-
-class DynamicModule(types.ModuleType):
-    """A module composed of an IntrospectionModule and an overrides module.
-
-    DynamicModule wraps up an IntrospectionModule and an overrides module
-    into a single accessible module. This is what is returned from statements
-    like "from gi.repository import Foo". Accessing attributes on a DynamicModule
-    will first look overrides (or the gi.overrides.registry cache) and then
-    in the introspection module if it was not found as an override.
-    """
-    def __init__(self, namespace):
-        self._namespace = namespace
-        self._introspection_module = None
-        self._overrides_module = None
-        self.__path__ = None
-
-    def _load(self):
-        self._introspection_module = get_introspection_module(self._namespace)
-        try:
-            self._overrides_module = importlib.import_module('gi.overrides.' + self._namespace)
-        except ImportError:
-            self._overrides_module = None
-
-        self.__path__ = repository.get_typelib_path(self._namespace)
-        if _have_py3:
-            # get_typelib_path() delivers bytes, not a string
-            self.__path__ = self.__path__.decode('UTF-8')
-
-    def __getattr__(self, name):
-        if self._overrides_module is not None:
-            override_exports = getattr(self._overrides_module, '__all__', ())
-            if name in override_exports:
-                return getattr(self._overrides_module, name, None)
-        else:
-            # check the registry just in case the module hasn't loaded yet
-            # TODO: Only gtypes are registered in the registry right now
-            #       but it would be nice to register all overrides and
-            #       get rid of the module imports. We might actually see a
-            #       speedup.
-            key = '%s.%s' % (self._namespace, name)
-            if key in registry:
-                return registry[key]
-
-        return getattr(self._introspection_module, name)
-
-    def __dir__(self):
-        # Python's default dir() is just dir(self.__class__) + self.__dict__.keys()
-        result = set(dir(self.__class__))
-        result.update(self.__dict__.keys())
-
-        result.update(dir(self._introspection_module))
-        override_exports = getattr(self._overrides_module, '__all__', ())
-        result.update(override_exports)
-        return list(result)
-
-    def __repr__(self):
-        path = repository.get_typelib_path(self._namespace)
-        if _have_py3:
-            # get_typelib_path() delivers bytes, not a string
-            path = path.decode('UTF-8')
-
-        return "<%s.%s %r from %r>" % (self.__class__.__module__,
-                                       self.__class__.__name__,
-                                       self._namespace,
-                                       path)
