@@ -382,7 +382,7 @@ pyg_value_from_pyobject_with_error(GValue *value, PyObject *obj)
     case G_TYPE_UINT:
     {
         if (PYGLIB_PyLong_Check(obj)) {
-            guint val;
+            gulong val;
 
             /* check that number is not negative */
             if (PyLong_AsLongLong(obj) < 0)
@@ -390,7 +390,7 @@ pyg_value_from_pyobject_with_error(GValue *value, PyObject *obj)
 
             val = PyLong_AsUnsignedLong(obj);
             if (val <= G_MAXUINT)
-                g_value_set_uint(value, val);
+                g_value_set_uint(value, (guint) val);
             else
                 return -1;
         } else {
@@ -933,17 +933,40 @@ pyg_strv_to_gvalue(GValue *value, PyObject *obj)
     Py_ssize_t argc, i;
     gchar **argv;
 
-    if (!(PyTuple_Check(obj) || PyList_Check(obj)))
+    if (!(PyTuple_Check (obj) || PyList_Check (obj)))
         return -1;
 
-    argc = PySequence_Length(obj);
-    for (i = 0; i < argc; ++i)
-	if (!PYGLIB_PyUnicode_Check(PySequence_Fast_GET_ITEM(obj, i)))
-	    return -1;
-    argv = g_new(gchar *, argc + 1);
-    for (i = 0; i < argc; ++i)
-	argv[i] = g_strdup(PYGLIB_PyUnicode_AsString(PySequence_Fast_GET_ITEM(obj, i)));
+    argc = PySequence_Length (obj);
+    argv = g_new (gchar *, argc + 1);
+    for (i = 0; i < argc; ++i) {
+        PyObject* item = PySequence_Fast_GET_ITEM (obj, i);
+        /* same as _pygi_marshal_from_py_utf8 */
+        if (PyUnicode_Check (item)) {
+            PyObject *pystr_obj = PyUnicode_AsUTF8String (item);
+            if (!pystr_obj) {
+                goto error;
+            }
+            argv[i] = g_strdup (PYGLIB_PyBytes_AsString (pystr_obj));
+            Py_DECREF (pystr_obj);
+        }
+#if PY_VERSION_HEX < 0x03000000
+        else if (PyString_Check (item)) {
+            argv[i] = g_strdup (PyString_AsString (item));
+        }
+#endif
+        else {
+            goto error;
+        }
+    }
+
     argv[i] = NULL;
-    g_value_take_boxed(value, argv);
+    g_value_take_boxed (value, argv);
     return 0;
+
+error:
+    for (i = i - 1; i >= 0; i--) {
+        g_free (argv[i]);
+    }
+    g_free (argv);
+    return -1;
 }
