@@ -20,7 +20,7 @@ class TestThread(unittest.TestCase):
         self.obj.connect('from-thread', self.from_thread_cb)
         self.obj.emit('emit-signal')
 
-    def testExtensionModule(self):
+    def test_extension_module(self):
         GLib.idle_add(self.idle_cb)
         GLib.timeout_add(50, self.timeout_cb)
         self.main.run()
